@@ -28,6 +28,7 @@
 #include "exchange-delegates.h"
 #include "exchange-delegates-user.h"
 
+#include <shell/e-shell.h>
 #include <mail/mail-ops.h>
 #include <mail/mail-send-recv.h>
 #include <mail/e-mail-local.h>
@@ -176,8 +177,17 @@ static void
 em_utils_delegates_done (CamelFolder *folder, CamelMimeMessage *msg, CamelMessageInfo *info,
 		       gint queued, const gchar *appended_uid, gpointer data)
 {
+	EShell *shell;
+	EShellBackend *shell_backend;
+	EMailSession *session;
+
+	/* XXX Dig up the EMailSession from the default EShell. */
+	shell = e_shell_get_default ();
+	shell_backend = e_shell_get_backend_by_name (shell, "mail");
+	session = e_mail_backend_get_session (E_MAIL_BACKEND (shell_backend));
+
 	camel_message_info_free (info);
-	mail_send ();
+	mail_send (session);
 }
 
 /**
@@ -442,7 +452,7 @@ exchange_delegates_user_edit (ExchangeAccount *account,
 			for (i = 0; i < EXCHANGE_DELEGATES_LAST; i++) {
 				combobox = comboboxes[i];
 				role = e_dialog_combo_box_get (combobox, exchange_perm_map);
-				role_name = g_strdup (map_to_full_role_name(role));
+				role_name = g_strdup (map_to_full_role_name (role));
 				g_string_append_printf (
 					role_name_final,
 					"<tr><td>%s:</td><td>%s</td></tr>",
@@ -464,7 +474,8 @@ exchange_delegates_user_edit (ExchangeAccount *account,
 				*/
 				camel_stream_printf (stream, "<br>%s", _("However, you are not permitted "
 							 "to see my private items."));
-			camel_data_wrapper_construct_from_stream (delegate_mail_text, stream, NULL);
+			camel_data_wrapper_construct_from_stream_sync (
+				delegate_mail_text, stream, NULL, NULL);
 			g_free (role_name);
 			g_string_free (role_name_final, TRUE);
 			g_object_unref (stream);
@@ -483,7 +494,8 @@ exchange_delegates_user_edit (ExchangeAccount *account,
 			stream = camel_stream_mem_new ();
 			part = camel_mime_part_new ();
 
-			camel_data_wrapper_construct_from_stream (delegate_mail_data, stream, NULL);
+			camel_data_wrapper_construct_from_stream_sync (
+				delegate_mail_data, stream, NULL, NULL);
 			g_object_unref (stream);
 			camel_medium_set_content (CAMEL_MEDIUM (part), delegate_mail_data);
 			g_object_unref (delegate_mail_data);
